summaryrefslogtreecommitdiff
path: root/tools/make-man-index.py
diff options
context:
space:
mode:
Diffstat (limited to 'tools/make-man-index.py')
-rwxr-xr-xtools/make-man-index.py25
1 files changed, 13 insertions, 12 deletions
diff --git a/tools/make-man-index.py b/tools/make-man-index.py
index 396188212..0618e2e67 100755
--- a/tools/make-man-index.py
+++ b/tools/make-man-index.py
@@ -1,36 +1,37 @@
+#!/usr/bin/env python3
# -*- Mode: python; coding: utf-8; indent-tabs-mode: nil -*- */
#
# This file is part of elogind.
#
# Copyright 2012 Lennart Poettering
# Copyright 2013 Zbigniew Jędrzejewski-Szmek
#
# elogind is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 2.1 of the License, or
# (at your option) any later version.
#
# elogind is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
-# along with elogind; If not, see <http://www.gnu.org/licenses/>.
+# along with systemd; If not, see <http://www.gnu.org/licenses/>.
import collections
import sys
import re
-from xml_helper import *
+from xml_helper import xml_parse, xml_print, tree
MDASH = ' — ' if sys.version_info.major >= 3 else ' -- '
TEMPLATE = '''\
-<refentry id="elogind.index" conditional="HAVE_PYTHON">
+<refentry id="systemd.index" conditional="HAVE_PYTHON">
<refentryinfo>
- <title>elogind.index</title>
- <productname>elogind</productname>
+ <title>systemd.index</title>
+ <productname>systemd</productname>
<authorgroup>
<author>
@@ -43,13 +44,13 @@ TEMPLATE = '''\
</refentryinfo>
<refmeta>
- <refentrytitle>elogind.index</refentrytitle>
+ <refentrytitle>systemd.index</refentrytitle>
<manvolnum>7</manvolnum>
</refmeta>
<refnamediv>
- <refname>elogind.index</refname>
- <refpurpose>List all manpages from the elogind project</refpurpose>
+ <refname>systemd.index</refname>
+ <refpurpose>List all manpages from the systemd project</refpurpose>
</refnamediv>
</refentry>
'''
@@ -58,7 +59,7 @@ SUMMARY = '''\
<refsect1>
<title>See Also</title>
<para>
- <citerefentry><refentrytitle>elogind.directives</refentrytitle><manvolnum>7</manvolnum></citerefentry>
+ <citerefentry><refentrytitle>systemd.directives</refentrytitle><manvolnum>7</manvolnum></citerefentry>
</para>
<para id='counts' />
@@ -1,36 +1,37 @@
# -*- Mode: python; coding: utf-8; indent-tabs-mode: nil -*- */
#
-# This file is part of elogind.
+# This file is part of systemd.
#
# Copyright 2012 Lennart Poettering
@@ -1,36 +1,37 @@
# Copyright 2013 Zbigniew Jędrzejewski-Szmek
#
-# elogind is free software; you can redistribute it and/or modify it
+# systemd is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 2.1 of the License, or
@@ -1,36 +1,37 @@
# (at your option) any later version.
#
-# elogind is distributed in the hope that it will be useful, but
+# systemd is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU